@@ -55,17 +55,26 @@ def _write_read_supcmu_i2c(i2c_master: I2CMaster,
     return i2c_master.read(address, read_length)
 
 
-def get_version_string(i2c_master: I2CMaster, address: int) -> str:
+def get_version_string(master: Union[I2CMaster, SupMCUSerialMaster], address: int = None, cmd_name: str = None) -> str:
     """
     Gets the version string for the module at the provided address
 
     :param i2c_master: The I2CMaster to use.
-    :param address: The address of the device to request information from.
+    :param address: The address of the device to request information from. Only required when using a :any:`I2CMaster`
+    :param cmd_name: The name of the module to request information from.  Only required when using a :any:`SupMCUSerialMaster`
     :return: The version string
     """
+
     module_def = SupMCUModuleDefinition("", "", address, {0: SUPMCU_VERSION_DEFINITION}, {})
-    master = SupMCUMaster(i2c_master, (module_def,))
-    version = master.request_telemetry(address, TelemetryType.SupMCU, 0).items[0].value
+    if isinstance(master, I2CMaster) and address is not None:
+        master = SupMCUMaster(master, (module_def,))
+        version = master.request_telemetry(address, TelemetryType.SupMCU, 0).items[0].value
+    elif isinstance(master, SupMCUSerialMaster) and cmd_name is not None:
+        version = master.send_command(cmd_name, 'SUP:TEL? 0,ASCII')
+    elif isinstance(master, I2CMaster) or isinstance(master, SupMCUSerialMaster):
+        raise TypeError("'address' or 'cmd_name' were not supplied, though they were needed")
+    else:
+        raise TypeError("'master' must either be an 'I2CMaster' or a 'SupMCUSerialMaster'")
     # print(version)
     return version
 
@@ -124,7 +133,7 @@ def set_values(master: Union[I2CMaster, SupMCUMaster, SupMCUSerialMaster],
     elif isinstance(master, SupMCUMaster):
         master.i2c_master.write(address, f'{module_cmd_name}:TEL {idx},{values}\n'.encode('ascii'))
     elif isinstance(master, SupMCUSerialMaster):
-        master.send_command(module_cmd_name, f'{module_cmd_name}:TEL {idx},{values}\n', response_delay)
+        master.send_command(module_cmd_name, f'{module_cmd_name}:TEL {idx},{values}\n')
 
 
 def request_telemetry_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
