@@ -13,7 +13,7 @@
 These data types are used throughout the :mod:`pumpkin_supmcu.supmcu` to type and structure the module definitions.
 """
 from enum import IntEnum
-from typing import Dict, Any, List
+from typing import Dict, Any, List, Optional
 from dataclasses import dataclass
 
 
@@ -120,6 +120,8 @@ class SupMCUTelemetryDefinition(object):
     telemetry_length: int
     idx: int
     format: str
+    simulatable: bool = False
+    defaults: Optional[Any] = None
 
 
 @dataclass
